@@ -1,4 +1,7 @@
-#include "E_DBus.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "e_dbus_private.h"
 
 /**
@@ -16,10 +19,9 @@ _dbus_peer_call(E_DBus_Connection *conn, const char *method_name, const char *de
     (destination, path, "org.freedesktop.DBus.Peer", method_name);
   if (!msg)
     {
-       fprintf(stderr,
-	       "ERROR: failed to create message for method call: %s() at "
-	       "\"%s\" at \"%s\"\n",
-	       method_name, destination, path);
+      ERR("E-dbus Error: failed to create message for method call: %s() at "
+	    "\"%s\" at \"%s\"",
+	    method_name, destination, path);
        return NULL;
     }
 
@@ -27,9 +29,9 @@ _dbus_peer_call(E_DBus_Connection *conn, const char *method_name, const char *de
   dbus_message_unref(msg);
 
   if (!ret)
-    fprintf(stderr, "ERROR: could not %s() \"%s\" at \"%s\".\n",
-	    method_name, destination, path);
-
+    ERR("E-dbus Error: could not %s() \"%s\" at \"%s\".",
+	  method_name, destination, path);
+  
   return ret;
 }
 
@@ -70,7 +72,7 @@ _dbus_message_property_method_call(E_DBus_Connection *conn, const char *method_n
 
   if (!conn)
     {
-       fprintf(stderr, "ERROR: no connection for call of %s\n", method_name);
+      ERR("E-dbus Error: no connection for call of %s", method_name);
        return NULL;
     }
 
@@ -78,11 +80,10 @@ _dbus_message_property_method_call(E_DBus_Connection *conn, const char *method_n
     (destination, path, "org.freedesktop.DBus.Properties", method_name);
   if (!msg)
     {
-       fprintf(stderr,
-	       "ERROR: failed to create message for method call: %s() at "
-	       "\"%s\" at \"%s\"\n",
-	       method_name, destination, path);
-       return NULL;
+      ERR("E-dbus Error: failed to create message for method call: %s() at "
+	    "\"%s\" at \"%s\"",
+	    method_name, destination, path);
+      return NULL;
     }
 
   if (property)
@@ -112,8 +113,8 @@ e_dbus_properties_get_all(E_DBus_Connection *conn, const char *destination, cons
   dbus_message_unref(msg);
 
   if (!ret)
-    fprintf(stderr, "ERROR: failed to call GetAll() at \"%s\" at \"%s\"\n",
-	    destination, path);
+    ERR("ERROR: failed to call GetAll() at \"%s\" at \"%s\"",
+	  destination, path);
 
   return ret;
 }
@@ -143,8 +144,8 @@ e_dbus_properties_get(E_DBus_Connection *conn, const char *destination, const ch
   dbus_message_unref(msg);
 
   if (!ret)
-    fprintf(stderr, "ERROR: failed to call Get() at \"%s\" at \"%s\"\n",
-	    destination, path);
+    ERR("E-dbus Error: failed to call Get() at \"%s\" at \"%s\"",
+	  destination, path);
 
   return ret;
 }
@@ -199,8 +200,8 @@ e_dbus_properties_set(E_DBus_Connection *conn, const char *destination, const ch
   dbus_message_unref(msg);
 
   if (!ret)
-    fprintf(stderr, "ERROR: failed to call Set() at \"%s\" at \"%s\"\n",
-	    destination, path);
+    ERR("E-dbus Error: failed to call Set() at \"%s\" at \"%s\"",
+	  destination, path);
 
   return ret;
 }
